#undef VERSION
#undef PACKAGE
#undef SOUND
#undef HAVE_LIBSM
#undef HAVE_ESD
#undef HAVE_SOCKS5
#undef HAVE_CATGETS
#undef HAVE_GETTEXT
#undef HAVE_LC_MESSAGES
#undef HAVE_STPCPY
#undef ENABLE_NLS
#undef HAVE_ICONV
#undef TRACE_FUNCTION
#undef USE_NEW_STORAGE
#undef USE_STATUS_MENU
#undef NO_SCARY_EYEBALLS
#undef USE_RUSSIAN
#undef HAVE_LIBGDBM
#undef HAVE_NDBM
#undef GNOME_ICON
